require 'faraday'
require 'faraday_middleware'

module JeffreyBotterhillClient
  class Client
    BASE_ENDPOINT = 'https://jeffrey-botterhill.herokuapp.com'
    LATEST_API_VERSION = 1

    def initialize(api_key:, endpoint: BASE_ENDPOINT, version: LATEST_API_VERSION)
      @endpoint = endpoint
      @api_key = api_key
      @version = version
    end

    def record_phrase(message:, source:, metadata: {})
      api_connection.post '/blurbs' do |req|
        req.body = { blurb: {
          message: message,
          source: source,
          metadata: metadata
        } }
      end
    end

    private
    def api_connection
      @api_connection ||= Faraday.new(:url => @endpoint) do |faraday|
        faraday.request :json
        faraday.request  :authorization, 'JeffreyBotterhill', @api_key
        faraday.response :json, :content_type => /\bjson$/
        faraday.adapter  Faraday.default_adapter
      end
    end
  end
end
